@@ -6,15 +6,10 @@ from pathlib import Path
 import typer
 from rich import print
 
-from . import connection
-from . import function
-from . import procedure
-from . import stage
-from . import streamlit
-from . import warehouse
 from .. import __about__
 from ..config import AppConfig
 from ..snowsql_config import SnowsqlConfig
+from . import connection, function, procedure, stage, streamlit, warehouse
 
 app = typer.Typer(context_settings={"help_option_names": ["-h", "--help"]})
 
@@ -28,15 +23,18 @@ def version_callback(value: bool):
 @app.command()
 def login(
     snowsql_config_path: Path = typer.Option(
-        '~/.snowsql/config',
-        '--config', '-c',
-        prompt='Path to Snowsql config',
-        help='snowsql config file',
+        "~/.snowsql/config",
+        "--config",
+        "-c",
+        prompt="Path to Snowsql config",
+        help="snowsql config file",
     ),
     snowsql_connection_name: str = typer.Option(
-        ..., '--connection', '-C',
-        prompt='Connection name (for entry in snowsql config)',
-        help='connection name from snowsql config file',
+        ...,
+        "--connection",
+        "-C",
+        prompt="Connection name (for entry in snowsql config)",
+        help="connection name from snowsql config file",
     ),
 ):
     """
@@ -50,17 +48,17 @@ def login(
     if f"connections.{snowsql_connection_name}" not in cfg_snowsql.config:
         print(
             "Connection not found in "
-            f"{snowsql_config_path}: {snowsql_connection_name}",
+            f"{snowsql_config_path}: {snowsql_connection_name}. ",
+            "You can add with `snow connection add`.",
         )
         raise typer.Abort()
 
     cfg = AppConfig()
-    cfg.config['snowsql_config_path'] = str(snowsql_config_path.expanduser())
-    cfg.config['snowsql_connection_name'] = snowsql_connection_name
+    cfg.config["snowsql_config_path"] = str(snowsql_config_path.expanduser())
+    cfg.config["snowsql_connection_name"] = snowsql_connection_name
     cfg.save()
     print(
-        "Using connection name "
-        f"{snowsql_connection_name} in {snowsql_config_path}",
+        "Using connection name " f"{snowsql_connection_name} in {snowsql_config_path}",
     )
     print(f"Wrote {cfg.path}")
 
@@ -68,28 +66,34 @@ def login(
 @app.command()
 def configure(
     environment: str = typer.Option(
-        'dev', '-e', '--environment',
-        help='Name of environment (e.g. dev, prod, staging)',
+        "dev",
+        "-e",
+        "--environment",
+        help="Name of environment (e.g. dev, prod, staging)",
     ),
     database: str = typer.Option(
-        ..., '--database',
-        prompt='Snowflake database',
-        help='Snowflake database',
+        ...,
+        "--database",
+        prompt="Snowflake database",
+        help="Snowflake database",
     ),
     schema: str = typer.Option(
-        ..., '--schema',
-        prompt='Snowflake schema',
-        help='Snowflake schema',
+        ...,
+        "--schema",
+        prompt="Snowflake schema",
+        help="Snowflake schema",
     ),
     role: str = typer.Option(
-        ..., '--role',
-        prompt='Snowflake role',
-        help='Snowflake role',
+        ...,
+        "--role",
+        prompt="Snowflake role",
+        help="Snowflake role",
     ),
     warehouse: str = typer.Option(
-        ..., '--warehouse',
-        prompt='Snowflake warehouse',
-        help='Snowflake warehouse',
+        ...,
+        "--warehouse",
+        prompt="Snowflake warehouse",
+        help="Snowflake warehouse",
     ),
 ):
     """
@@ -104,10 +108,10 @@ def configure(
         raise typer.Abort()
 
     cfg.config[environment] = {}
-    cfg.config[environment]['database'] = database
-    cfg.config[environment]['schema'] = schema
-    cfg.config[environment]['role'] = role
-    cfg.config[environment]['warehouse'] = warehouse
+    cfg.config[environment]["database"] = database
+    cfg.config[environment]["schema"] = schema
+    cfg.config[environment]["role"] = role
+    cfg.config[environment]["warehouse"] = warehouse
     cfg.save()
     print(f"Wrote environment {environment} to {cfg.path}")
 
@@ -115,8 +119,10 @@ def configure(
 @app.callback()
 def default(
     version: bool = typer.Option(
-        None, "--version",
-        callback=version_callback, is_eager=True,
+        None,
+        "--version",
+        callback=version_callback,
+        is_eager=True,
     ),
 ) -> None:
     """
@@ -131,8 +137,8 @@ app.add_typer(connection.app, name="connection")
 app.add_typer(warehouse.app, name="warehouse")
 app.add_typer(stage.app, name="stage")
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     app()
 
-if getattr(sys, 'frozen', False):
+if getattr(sys, "frozen", False):
     app(sys.argv[1:])
