@@ -318,6 +318,44 @@ class SnowflakeConnector:
             },
         )
 
+    def createStage(
+        self,
+        database,
+        schema,
+        role,
+        warehouse,
+        name,
+    ) -> SnowflakeCursor:
+        return self.runSql(
+            "create_stage",
+            {
+                "database": database,
+                "schema": schema,
+                "role": role,
+                "warehouse": warehouse,
+                "name": name,
+            },
+        )
+
+    def dropStage(
+        self,
+        database,
+        schema,
+        role,
+        warehouse,
+        name,
+    ) -> SnowflakeCursor:
+        return self.runSql(
+            "drop_stage",
+            {
+                "database": database,
+                "schema": schema,
+                "role": role,
+                "warehouse": warehouse,
+                "name": name,
+            },
+        )
+
     def listProcedures(
         self,
         database,
@@ -381,7 +419,6 @@ class SnowflakeConnector:
         schema="",
         role="",
         warehouse="",
-        like="%%",
     ) -> SnowflakeCursor:
         return self.runSql(
             "list_streamlits",
@@ -432,6 +469,51 @@ class SnowflakeConnector:
             },
         )
 
+    def shareStreamlit(
+        self,
+        database="",
+        schema="",
+        role="",
+        warehouse="",
+        name="",
+        to_role="",
+    ) -> SnowflakeCursor:
+        return self.runSql(
+            "share_streamlit",
+            {
+                "database": database,
+                "schema": schema,
+                "role": role,
+                "warehouse": warehouse,
+                "name": name,
+                "to_role": to_role,
+            },
+        )
+
+    def dropStreamlit(
+        self,
+        database="",
+        schema="",
+        role="",
+        warehouse="",
+        name="",
+        drop_stage: bool = True,
+    ) -> SnowflakeCursor:
+
+        drop_command = f"drop stage {name}_stage;" if drop_stage else ""
+
+        return self.runSql(
+            "drop_streamlit",
+            {
+                "database": database,
+                "schema": schema,
+                "role": role,
+                "warehouse": warehouse,
+                "name": name,
+                "drop_command": drop_command,
+            },
+        )
+
     def deployStreamlit(
         self,
         name,
